@@ -19,7 +19,7 @@ __all__ = [
 
 import math
 import warnings
-from typing import Any, Optional, Union
+from typing import Any
 
 from pyproj._geod import Geod as _Geod
 from pyproj._geod import GeodIntermediateReturn, geodesic_version_str
@@ -47,18 +47,12 @@ def _params_from_ellps_map(ellps: str) -> tuple[float, float, float, float, bool
 
     """
     ellps_dict = pj_ellps[ellps]
-    semi_major_axis: float = ellps_dict["a"]
+    semi_major_axis, semi_minor_axis, flattening, eccentricity_squared = (
+        _params_from_kwargs(ellps_dict)
+    )
     sphere = False
     if ellps_dict["description"] == "Normal Sphere":
         sphere = True
-    if "b" in ellps_dict:
-        semi_minor_axis: float = ellps_dict["b"]
-        eccentricity_squared: float = 1.0 - semi_minor_axis**2 / semi_major_axis**2
-        flattening: float = (semi_major_axis - semi_minor_axis) / semi_major_axis
-    elif "rf" in ellps_dict:
-        flattening = 1.0 / ellps_dict["rf"]
-        semi_minor_axis = semi_major_axis * (1.0 - flattening)
-        eccentricity_squared = 1.0 - semi_minor_axis**2 / semi_major_axis**2
     return semi_major_axis, semi_minor_axis, flattening, eccentricity_squared, sphere
 
 
@@ -146,7 +140,7 @@ class Geod(_Geod):
 
     """
 
-    def __init__(self, initstring: Optional[str] = None, **kwargs) -> None:
+    def __init__(self, initstring: str | None = None, **kwargs) -> None:
         """
         initialize a Geod class instance.
 
@@ -203,7 +197,7 @@ class Geod(_Geod):
         """
         # if initparams is a proj-type init string,
         # convert to dict.
-        ellpsd: dict[str, Union[str, float]] = {}
+        ellpsd: dict[str, str | float] = {}
         if initstring is not None:
             for kvpair in initstring.split():
                 # Actually only +a and +b are needed
@@ -551,10 +545,10 @@ class Geod(_Geod):
         terminus_idx: int = 1,
         radians: bool = False,
         flags: GeodIntermediateFlag = GeodIntermediateFlag.DEFAULT,
-        out_lons: Optional[Any] = None,
-        out_lats: Optional[Any] = None,
-        out_azis: Optional[Any] = None,
-        return_back_azimuth: Optional[bool] = None,
+        out_lons: Any | None = None,
+        out_lats: Any | None = None,
+        out_azis: Any | None = None,
+        return_back_azimuth: bool | None = None,
     ) -> GeodIntermediateReturn:
         """
         .. versionadded:: 3.1.0
@@ -714,10 +708,10 @@ class Geod(_Geod):
         terminus_idx: int = 1,
         radians: bool = False,
         flags: GeodIntermediateFlag = GeodIntermediateFlag.DEFAULT,
-        out_lons: Optional[Any] = None,
-        out_lats: Optional[Any] = None,
-        out_azis: Optional[Any] = None,
-        return_back_azimuth: Optional[bool] = None,
+        out_lons: Any | None = None,
+        out_lats: Any | None = None,
+        out_azis: Any | None = None,
+        return_back_azimuth: bool | None = None,
     ) -> GeodIntermediateReturn:
         """
         .. versionadded:: 3.1.0
